@@ -73,8 +73,50 @@ fitSubmodels <- function(model,
       } else {
         return(LL.sum)
       }
-    }
-    else {
+    } else if (control$sem.prog == 'ctsem') {
+        ###########################################################
+        ###               ctsemOMX USED HERE                    ###
+        ###########################################################
+      model1 <- try(ctsemOMX::ctFit(dat = subset1,
+                                    ctmodelobj = model$ctmodelobj,
+                                    dataform = "wide",
+                                    objective = model$ctfitargs$objective,
+                                    stationary = model$ctfitargs$stationary,
+                                    optimizer = model$ctfitargs$optimizer,
+                                    retryattempts = ifelse(model$ctfitargs$retryattempts >= 20,
+                                                           yes = model$ctfitargs$retryattempts,
+                                                           no = 20),
+                                    carefulFit = model$ctfitargs$carefulFit,
+                                    showInits = model$ctfitargs$showInits,
+                                    asymptotes = model$ctfitargs$asymptotes,
+                                    meanIntervals = model$ctfitargs$meanIntervals,
+                                    discreteTime = model$ctfitargs$discreteTime,
+                                    verbose = model$ctfitargs$verbose,
+                                    transformedParams = model$ctfitargs$transformedParams),
+                    silent = TRUE)
+      if (is(model1,"try-error")) {return(NA)}
+      model2 <- try(ctsemOMX::ctFit(dat = subset2,
+                                    ctmodelobj = model$ctmodelobj,
+                                    dataform = "wide",
+                                    objective = model$ctfitargs$objective,
+                                    stationary = model$ctfitargs$stationary,
+                                    optimizer = model$ctfitargs$optimizer,
+                                    retryattempts = ifelse(model$ctfitargs$retryattempts >= 20,
+                                                           yes = model$ctfitargs$retryattempts,
+                                                           no = 20),
+                                    carefulFit = model$ctfitargs$carefulFit,
+                                    showInits = model$ctfitargs$showInits,
+                                    asymptotes = model$ctfitargs$asymptotes,
+                                    meanIntervals = model$ctfitargs$meanIntervals,
+                                    discreteTime = model$ctfitargs$discreteTime,
+                                    verbose = model$ctfitargs$verbose,
+                                    transformedParams = model$ctfitargs$transformedParams),
+                    silent = TRUE)
+      if (is(model2,"try-error")) {return(NA)}
+      fit1 <- minus2logLik_from_fitted_models(model1)
+      fit2 <- minus2logLik_from_fitted_models(model2)
+      LL.sum <- fit1 + fit2
+      } else {
       
       # check subgroups for empty columns in modeled variables...
       modelcheck <- unlist(model@Data@ov.names)
@@ -257,7 +299,7 @@ fitSubmodels <- function(model,
         mxFitFunctionAlgebra('h12')
       )
       
-      sharedRun <- mxRun(sharedModel, silent = T)
+      sharedRun <- mxRun(sharedModel, silent = TRUE)
       
       LL.sum <-  mxEval(h12, sharedRun)
       
